@@ -151,10 +151,12 @@ ServiceName = Literal[
     "amp",
     "amplify",
     "amplifybackend",
+    "amplifyuibuilder",
     "apigateway",
     "apigatewaymanagementapi",
     "apigatewayv2",
     "appconfig",
+    "appconfigdata",
     "appflow",
     "appintegrations",
     "application-autoscaling",
@@ -169,6 +171,7 @@ ServiceName = Literal[
     "autoscaling",
     "autoscaling-plans",
     "backup",
+    "backup-gateway",
     "batch",
     "braket",
     "budgets",
@@ -223,6 +226,7 @@ ServiceName = Literal[
     "dlm",
     "dms",
     "docdb",
+    "drs",
     "ds",
     "dynamodb",
     "dynamodbstreams",
@@ -244,6 +248,7 @@ ServiceName = Literal[
     "emr-containers",
     "es",
     "events",
+    "evidently",
     "finspace",
     "finspace-data",
     "firehose",
@@ -270,6 +275,7 @@ ServiceName = Literal[
     "imagebuilder",
     "importexport",
     "inspector",
+    "inspector2",
     "iot",
     "iot-data",
     "iot-jobs-data",
@@ -283,6 +289,7 @@ ServiceName = Literal[
     "iotsecuretunneling",
     "iotsitewise",
     "iotthingsgraph",
+    "iottwinmaker",
     "iotwireless",
     "ivs",
     "kafka",
@@ -328,7 +335,9 @@ ServiceName = Literal[
     "meteringmarketplace",
     "mgh",
     "mgn",
+    "migration-hub-refactor-spaces",
     "migrationhub-config",
+    "migrationhubstrategy",
     "mobile",
     "mq",
     "mturk",
@@ -357,11 +366,13 @@ ServiceName = Literal[
     "qldb-session",
     "quicksight",
     "ram",
+    "rbin",
     "rds",
     "rds-data",
     "redshift",
     "redshift-data",
     "rekognition",
+    "resiliencehub",
     "resource-groups",
     "resourcegroupstaggingapi",
     "robomaker",
@@ -371,6 +382,7 @@ ServiceName = Literal[
     "route53-recovery-readiness",
     "route53domains",
     "route53resolver",
+    "rum",
     "s3",
     "s3control",
     "s3outposts",
@@ -428,6 +440,7 @@ ServiceName = Literal[
     "workmail",
     "workmailmessageflow",
     "workspaces",
+    "workspaces-web",
     "xray",
 ]
 PaginatorName = Literal[
